@@ -178,12 +178,15 @@ private:
 
     void fallbackDialout (DialContext *ctx);
 
+    void setMqSettingsInQml(bool bEnable, const QString &host, int port,
+                            const QString &topic);
+
 private:
     //! Logfile
     QFile           fLogfile;
 
     // Tray, icons, widgets
-    QIcon           icoGoogle;
+    QIcon           icoQgv;
     QSystemTrayIcon *pSystray;
     //! GV Contacts object
     GVContactsTable oContacts;
