@@ -71,6 +71,7 @@ SkypeClient::enqueueWork (Skype_Work whatwork, const QVariantList &params,
         }
         break;
 
+    case SW_SendDtmf:
     case SW_GetCallInfo:
         // Count of params must be = 1
         if (1 != params.size ())
@@ -139,6 +140,9 @@ SkypeClient::doNextWork ()
         case SW_GetCallInfo:
             getCallInfo ();
             break;
+        case SW_SendDtmf:
+            sendDTMF ();
+            break;
         default:
             qDebug ("SkypeClient: Invalid work specified. Moving on to next work.");
             workCurrent.init ();
@@ -208,6 +212,9 @@ SkypeClient::getNameForWork (Skype_Work whatwork)
     case SW_GetCallInfo:
         func = "GetCallInfo";
         break;
+    case SW_SendDtmf:
+        func = "SendDtmf";
+        break;
     default:
         func = "unknown";
         break;
@@ -281,6 +288,7 @@ SkypeClient::callInitiated (int status, const QString &strOutput)
                         << workCurrent.arrParams[0].toString ();
             break;
         }
+        rv = false;
 
         QString strStatus = strOutput;
         strStatus.remove ("CALL ");
@@ -294,7 +302,7 @@ SkypeClient::callInitiated (int status, const QString &strOutput)
         }
 
         strStatus = rx.cap (2);
-        uint callId = rx.cap (1).toULong ();
+        ulong callId = rx.cap (1).toULong ();
 
         emit callStatusChanged (callId, strStatus);
 
@@ -323,6 +331,7 @@ SkypeClient::ensureConnected ()
     // to override this function and do some real work.
     bConnected = true;
     completeCurrentWork (SW_Connect, true);
+    emit connectedChanged (bConnected);
     return (true);
 }//SkypeClient::ensureConnected
 
@@ -407,11 +416,10 @@ SkypeClient::onGotContacts (int status, const QString &strOutput)
 bool
 SkypeClient::skypeNotifyPre (const QString &strData)
 {
-    qDebug () << "SkypeClient: Skype notify : " << strData;
+    qDebug() << "SkypeClient: Skype notify : " << strData;
 
     bool rv = true;
-    do // Begin cleanup block (not a loop)
-    {
+    do { // Begin cleanup block (not a loop)
         if (strData.startsWith ("CONNDATA"))
         {
             break;
@@ -428,7 +436,6 @@ SkypeClient::skypeNotifyPre (const QString &strData)
         {
             break;
         }
-
         if (strData.startsWith ("CALL "))
         {
             QMutexLocker locker (&mutex);
@@ -450,7 +457,7 @@ SkypeClient::skypeNotifyPre (const QString &strData)
             }
 
             strStatus = rx.cap (2);
-            uint callId = rx.cap (1).toULong ();
+            ulong callId = rx.cap (1).toULong ();
 
             emit callStatusChanged (callId, strStatus);
 
@@ -461,8 +468,15 @@ SkypeClient::skypeNotifyPre (const QString &strData)
                 if ((strText.contains ("MISSED")) ||
                     (strText.contains ("FINISHED")))
                 {
-                    qDebug () << "SkypeClient: Remove call id=" << callId;
+                    qDebug() << "SkypeClient: Remove call id =" << callId;
                     mapCallInfo.remove (callId);
+                    if (mapCallInfo.size () == 0) {
+                        qDebug ("SkypeClient: All calls are over");
+                    }
+                }
+                else if (strText.contains ("INPROGRESS")) {
+                    mapCallInfo[callId].bInprogress = true;
+                    sendDTMF (QString(), false);
                 }
             }
 
@@ -523,8 +537,7 @@ SkypeClient::getCallInfo ()
         rv = true;
     }while (0);
 
-    if (!rv)
-    {
+    if (!rv) {
         completeCurrentWork (SW_GetCallInfo, false);
     }
 }//SkypeClient::getCallInfo
@@ -828,3 +841,77 @@ SkypeClient::onCI_GetTarget (uint incomingCallId, const QString &strOutput,
 
     completeCurrentWork (SW_GetCallInfo, rv);
 }//SkypeClient::onCI_GetTarget
+
+void
+SkypeClient::sendDTMF ()
+{
+    bool rv = false;
+    do {
+        if (!bConnected)
+        {
+            qWarning ("SkypeClient: Skype not connected");
+            break;
+        }
+
+        QString strTones = workCurrent.arrParams[0].toString ();
+        if (strTones.isEmpty ())
+        {
+            qWarning ("SkypeClient: No DTMF tones??");
+            break;
+        }
+
+        rv = sendDTMF (strTones, true);
+    }while (0);
+    completeCurrentWork (SW_SendDtmf, rv);
+}//SkypeClient::sendDTMF
+
+bool
+SkypeClient::sendDTMF (QString strTones, bool bFirstTime)
+{
+    bool rv = true;
+    QList<ulong>ids = mapCallInfo.keys ();
+    Skype_CallInfoMap::Iterator mapIter =  mapCallInfo.begin ();
+    for (; mapIter != mapCallInfo.end (); mapIter++) {
+        if (!mapIter->bInprogress) {
+            if (bFirstTime) {
+                qDebug() << "SkypeClient: Call" << mapIter.key()
+                         << "not in progress. Defering tones";
+                mapIter->strDeferredTones += strTones;
+            } else {
+                qDebug() << "SkypeClient: Call" << mapIter.key()
+                         << "still not in progress at repeat invocation.";
+            }
+            ids.removeOne (mapIter.key ());
+        }
+    }
+
+    if (ids.size () == 0) {
+        return true;
+    }
+
+    rv = true;
+    foreach (ulong callId, ids) {
+        if (!bFirstTime) {
+            strTones = mapCallInfo[callId].strDeferredTones;
+        }
+
+        foreach (QChar chTone, strTones) {
+            QThread::sleep (1);
+            if (chTone == 'p') {
+                QThread::sleep (1);
+                continue;
+            }
+            QString cmd = QString ("SET CALL %1 DTMF %2")
+                            .arg (callId).arg (chTone);
+            rv = invoke (cmd);
+            if (!rv)
+            {
+                qWarning ("SkypeClient: Failed to send DTMF tone");
+                rv = false;
+                break;
+            }
+        }
+    }
+
+    return rv;
+}//SkypeClient::sendDTMF (const QString &strTones)
