@@ -20,7 +20,8 @@ public:
     bool isValid ();
 
 public slots:
-    void initiateCall (const QString &strDestination);
+    void initiateCall (const QString &strDestination, void *ctx = NULL);
+    bool sendDTMF(const QString &strTones);
 
 private slots:
     void onConnectionChanged (const Tp::ConnectionPtr &connection);
